Security Advisories (12)
CVE-2018-14041 (2018-07-13)

In Bootstrap before 4.1.2, XSS is possible in the data-target property of scrollspy.

CVE-2018-14042 (2018-07-13)

In Bootstrap before 4.1.2, XSS is possible in the data-container property of tooltip.

CVE-2020-11022 (2020-04-29)

In jQuery versions greater than or equal to 1.2 and before 3.5.0, passing HTML from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2020-11023 (2020-04-29)

In jQuery versions greater than or equal to 1.0.3 and before 3.5.0, passing HTML containing <option> elements from untrusted sources - even after sanitizing it - to one of jQuery's DOM manipulation methods (i.e. .html(), .append(), and others) may execute untrusted code. This problem is patched in jQuery 3.5.0.

CVE-2019-11358 (2019-04-20)

jQuery before 3.4.0, as used in Drupal, Backdrop CMS, and other products, mishandles jQuery.extend(true, {}, ...) because of Object.prototype pollution. If an unsanitized source object contained an enumerable __proto__ property, it could extend the native Object.prototype.

CVE-2015-9251 (2018-01-18)

jQuery before 3.0.0 is vulnerable to Cross-site Scripting (XSS) attacks when a cross-domain Ajax request is performed without the dataType option, causing text/javascript responses to be executed.

CVE-2011-4969 (2013-03-08)

Cross-site scripting (XSS) vulnerability in jQuery before 1.6.3, when using location.hash to select elements, allows remote attackers to inject arbitrary web script or HTML via a crafted tag.

CVE-2012-6708 (2018-01-18)

jQuery before 1.9.0 is vulnerable to Cross-site Scripting (XSS) attacks. The jQuery(strInput) function does not differentiate selectors from HTML in a reliable fashion. In vulnerable versions, jQuery determined whether the input was HTML by looking for the '<' character anywhere in the string, giving attackers more flexibility when attempting to construct a malicious payload. In fixed versions, jQuery only deems the input to be HTML if it explicitly starts with the '<' character, limiting exploitability only to attackers who can control the beginning of a string, which is far less common.

CVE-2020-7656 (2020-05-19)

jquery prior to 1.9.0 allows Cross-site Scripting attacks via the load method. The load method fails to recognize and remove "<script>" HTML tags that contain a whitespace character, i.e: "</script >", which results in the enclosed script logic to be executed.

CVE-2019-5428

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

CVE-2014-6071 (2018-01-16)

jQuery 1.4.2 allows remote attackers to conduct cross-site scripting (XSS) attacks via vectors related to use of the text method inside after.

CVE-2018-14040 (2018-07-13)

Prototype Pollution is a vulnerability affecting JavaScript. Prototype Pollution refers to the ability to inject properties into existing JavaScript language construct prototypes, such as objects. JavaScript allows all Object attributes to be altered, including their magical attributes such as _proto_, constructor and prototype. An attacker manipulates these attributes to overwrite, or pollute, a JavaScript application object prototype of the base object by injecting other values. Properties on the Object.prototype are then inherited by all the JavaScript objects through the prototype chain. When that happens, this leads to either denial of service by triggering JavaScript exceptions, or it tampers with the application source code to force the code path that the attacker injects, thereby leading to remote code execution.

NAME

YATT::Lite::Object - fields based, Tcl/Tk like object

SYNOPSIS

package MyProduct {
   sub MY () {__PACKAGE__}          # Shorthand alias.
   use base qw/YATT::Lite::Object/; # For fields, you must use 'base'.
   use fields qw/cf_name cf_price/; # Or YATT::Lite::MFields, if you like.

   sub as_string {
     (my MY $self, my ($fmt)) = @_;
     $fmt //= '%s (%d)';
     sprintf $fmt, $self->{cf_name}, $self->{cf_price}; # statically checked!
   }
}

1;

Then you can use this class like this:

my $prod = MyProduct->new(name => 'foo', price => 100);
print $prod->cget('name');

DESCRIPTION

XXX: See YATT::Lite::docs::whyfields. (But it is not yet translated to English:-<)

METHODS

new

my $obj = YATT::Lite::Object->new(cf1 => val1, cf2 => val2, ...);

my $obj = YATT::Lite::Object->new({cf1 => val1, cf2 => val2, ...});

configure

Bulk setter(sets multiple configs at once).

$obj->configure(cf1 => val1, cf2 => val2, ...);

$obj->configure({cf1 => val1, cf2 => val2, ...});

cget

$obj->cget('cf1')

$obj->cget('cf1', 'default')

HOOKS

configure_CFx

If your class has method named configure_CFx, it is called whenever $obj->configure(CFx => val) is called.

after_new

Mainly used for initializing default config values. Typical code will be:

sub after_new {
  (my MY $self) = @_;
  $self->SUPER::after_new;
  $self->{cf_xxx} //= "foo";
  $self->{cf_yyy} //= "bar";
  # ...
}

_before_after_new

Ideally, having two hooks is useless. But user-level programmers could forget to call SUPER::new in their <after_new> hook, which can lead hard to debug situation. So, I divided hooks, one for user-level programmers and the other for framework designers. This _before_after_new is the later one.